pub fn init() -> boolExpand description
Initializes the cache by loading all assemblies and resetting prior state.
Also performs an eager full class hydration pass.
This is primarily used internally by crate::init.
pub fn init() -> boolInitializes the cache by loading all assemblies and resetting prior state.
Also performs an eager full class hydration pass.
This is primarily used internally by crate::init.