Time

Struct Time 

pub struct Time;
Accessors for selected UnityEngine.Time properties.

Implementations

Source

impl Time

pub fn get_class() -> Option<Class>

Gets the UnityEngine.Time class

pub fn get_time() -> f32

The time at the beginning of this frame (Read Only)

pub fn get_delta_time() -> f32

The time in seconds it took to complete the last frame (Read Only)

pub fn get_fixed_delta_time() -> f32

The interval in seconds at which physics and other fixed frame rate updates (like MonoBehaviour’s FixedUpdate) are performed.

pub fn get_time_scale() -> f32

The scale at which time passes. This can be used for slow motion effects.

pub fn set_time_scale(value: f32)

Sets the scale at which time passes.