Module logger

Module logger 

Logging via platform-appropriate logging backend.

On Apple platforms (macOS/iOS) the Apple Unified Logging System is used via oslog. On all other platforms env_logger is used, which writes to stderr and respects the RUST_LOG environment variable.

Functions

error
info
warning