Module image

Module image 

Functions

get_image_base
Returns the base address of the image with the given name, if loaded.
get_image_path
Returns the full filesystem path of the loaded image matching name, if found.