ComponentTrait

Trait ComponentTrait 

pub trait ComponentTrait {
    // Required method
    fn from_ptr(ptr: *mut c_void) -> Self;
}
Trait implemented by Unity component wrappers that can be constructed from a raw pointer.

Required Methods

fn from_ptr(ptr: *mut c_void) -> Self

Creates the wrapper from a raw managed object pointer.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors