Struct LayerMask
Source #[repr(transparent)]
pub struct LayerMask {
pub value: i32,
}
Gets the LayerMask class definition
Returns
Option<Class> - The UnityEngine.LayerMask class
Converts a layer name to a layer index
Arguments
name - The name of the layer
Returns
i32 - The layer index, or -1 if not found
Converts a layer index to a layer name
Arguments
Returns
String - The name of the layer
Gets a mask for the specified layer names
Arguments
layer_names - A list of layer names to include in the mask
Returns
LayerMask - The resulting bitmask
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Converts to this type from the input type.
Converts to this type from the input type.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Checks if this value is equivalent to the given key.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.