#[repr(i32)]pub enum ForceMode {
Force = 0,
Acceleration = 5,
Impulse = 1,
VelocityChange = 2,
}Variants
Force = 0
Applies a continuous force to the rigidbody, using its mass
Acceleration = 5
Applies a continuous acceleration to the rigidbody, ignoring its mass
Impulse = 1
Applies an instant force impulse to the rigidbody, using its mass
VelocityChange = 2
Applies an instant velocity change to the rigidbody, ignoring its mass