Struct Scene
Source #[repr(C)]
pub struct Scene {
pub handle: i32,
}
handle: i32Handle to the underlying scene
Checks if the scene is valid
Returns
bool - True if the scene is valid
Gets the build index of the scene
Returns
i32 - The index in Build Settings, or -1 if not found
Checks if the scene is loaded
Returns
bool - True if the scene is currently loaded
Gets the name of the scene
Returns
String - The name of the scene
Gets the path of the scene asset
Returns
String - The asset path of the scene
Gets the count of root game objects in the scene
Returns
i32 - The number of root GameObjects
Gets all root game objects in the scene
Returns
Vec<GameObject> - A list of all root GameObjects
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Checks if this value is equivalent to the given key.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.