Property

Struct Property 

pub struct Property {
    pub name: String,
    pub type_info: Type,
    pub getter: Option<Method>,
    pub setter: Option<Method>,
    pub is_static: bool,
    pub access: &'static str,
    pub instance: Option<*mut c_void>,
}
Property metadata synthesized from getter and setter methods.

Fields

name: String

Name of the property (without get_/set_ prefix)

type_info: Type

Type of the property

getter: Option<Method>

Getter method (if exists)

setter: Option<Method>

Setter method (if exists)

is_static: bool

Whether the property is static

access: &'static str

Access modifier

instance: Option<*mut c_void>

Instance pointer for instance properties

Implementations

Source

impl Property

pub fn from_methods( getter: Option<Method>, setter: Option<Method>, ) -> Option<Self>

Creates a new Property from getter and/or setter methods

pub fn with_instance(&self, instance: *mut c_void) -> Self

Returns a copy of this property with the instance pointer set

pub fn has_getter(&self) -> bool

Returns true if this property has a getter

pub fn has_setter(&self) -> bool

Returns true if this property has a setter

pub unsafe fn get_value<T: Copy>(&self) -> Result<T, String>

Reads the property value through its getter.

For instance properties, the property must have a bound instance pointer. Use crate::structs::Object::property to obtain one.

pub unsafe fn set_value<T>(&self, value: T) -> Result<(), String>

Writes a property value through its setter.

For instance properties, the property must have a bound instance pointer. Use crate::structs::Object::property to obtain one.