Assembly

Struct Assembly 

pub struct Assembly {
    pub image: Image,
    pub address: *mut c_void,
    pub file: String,
    pub name: String,
    pub classes: Vec<Class>,
}
Represents a hydrated IL2CPP assembly.

In normal usage, values of this type come from crate::api::cache helper functions such as crate::api::cache::csharp.

Fields

image: Image

Wrapper for the image associated with this assembly

address: *mut c_void

Pointer to the internal IL2CPP assembly structure

file: String

Filename of the assembly (e.g. “Assembly-CSharp.dll”)

name: String

Name of the assembly (e.g. “Assembly-CSharp”)

classes: Vec<Class>

List of classes defined in this assembly

Implementations

Source

impl Assembly

pub fn class(&self, name: &str) -> Option<Class>

Finds a class by name within the assembly.

Accepts either a fully qualified type name such as UnityEngine.GameObject or an unqualified name for the global namespace.

pub fn dump(&self) -> &Self

Dumps this assembly into a C#-like pseudo-code file and returns self.

This is mainly intended for debugging and offline inspection.