BVec4A

Struct BVec4A 

pub struct BVec4A(/* private fields */);
A 4-dimensional SIMD vector mask.

This type is 16 byte aligned.

Implementations

Source

impl BVec4A

pub const FALSE: BVec4A

All false.

pub const TRUE: BVec4A

All true.

pub const fn new(x: bool, y: bool, z: bool, w: bool) -> BVec4A

Creates a new vector mask.

pub const fn splat(v: bool) -> BVec4A

Creates a vector mask with all elements set to v.

pub const fn from_array(a: [bool; 4]) -> BVec4A

Creates a new vector mask from a bool array.

pub fn bitmask(self) -> u32

Returns a bitmask with the lowest 4 bits set from the elements of self.

A true element results in a 1 bit and a false element in a 0 bit. Element x goes into the first lowest bit, element y into the second, etc.

pub fn any(self) -> bool

Returns true if any of the elements are true, false otherwise.

pub fn all(self) -> bool

Returns true if all the elements are true, false otherwise.

pub fn test(self, index: usize) -> bool

Tests the value at index.

Panics if index is greater than 3.

pub fn set(&mut self, index: usize, value: bool)

Sets the element at index.

Panics if index is greater than 3.