Module ptr

Module ptr 

Pointer utilities Safe wrapper for valid mutable pointers

This module provides the MutPtr wrapper which guarantees non-null pointer access with safe ergonomic wrappers while maintaining the raw pointer representation.

Structs

MutPtr
A transparent wrapper around a mutable pointer that ensures safety checks on access