Function load
Source pub fn load(
loader: impl Fn(&str) -> *mut c_void,
) -> Result<usize, Vec<&'static str>>
Initializes the IL2CPP functions using the provided loader
Arguments
loader - A closure that takes a symbol name and returns a pointer to it
Errors
Returns the list of missing symbol names if any required export could not be resolved.