pub fn assembly(name: &str) -> Option<Arc<Assembly>>
Retrieves an assembly by name.
The name may be provided with or without the .dll suffix.
.dll
Returns a cheap Arc clone if the assembly exists in the hydrated cache.
Arc