pub struct Il2CppCache {
pub assemblies: DashMap<String, Arc<Assembly>>,
pub classes: DashMap<String, Box<Class>>,
pub methods: DashMap<String, Method>,
}Expand description
Caches IL2CPP assemblies, classes, and methods
Fields
assemblies: DashMap<String, Arc<Assembly>>Helper map of assembly names to Assembly structs (Arc for cheap cloning)
classes: DashMap<String, Box<Class>>Helper map of class names to Class structs (boxed)
methods: DashMap<String, Method>Helper map of method keys to Method structs