Small wrappers for selected Unity APIs.
These modules provide convenience accessors for common static Unity classes without changing the underlying runtime model used elsewhere in the crate.
Modules
- application
- Thin wrapper around
UnityEngine.Application. - time
- Thin wrapper around
UnityEngine.Time.