pub struct Time;Expand description
Accessors for selected UnityEngine.Time properties.
Implementations
Sourceimpl Time
impl Time
Sourcepub fn get_delta_time() -> f32
pub fn get_delta_time() -> f32
The time in seconds it took to complete the last frame (Read Only)
Sourcepub fn get_fixed_delta_time() -> f32
pub fn get_fixed_delta_time() -> f32
The interval in seconds at which physics and other fixed frame rate updates (like MonoBehaviour’s FixedUpdate) are performed.
Sourcepub fn get_time_scale() -> f32
pub fn get_time_scale() -> f32
The scale at which time passes. This can be used for slow motion effects.
Sourcepub fn set_time_scale(value: f32)
pub fn set_time_scale(value: f32)
Sets the scale at which time passes.