Module structs

Module structs 

Metadata, object, collection, and wrapper types exposed by the crate.

The types in this module are the main building blocks once initialization has completed:

Prefer starting from crate::api::cache to discover assemblies and classes, then move into these types for inspection, invocation, and object access.

Re-exports

pub use collections::Il2cppString;
pub use components::GameObject;
pub use components::MonoBehaviour;
pub use components::Transform;
pub use core::Arg;
pub use core::Assembly;
pub use core::Class;
pub use core::Coroutine;
pub use core::Field;
pub use core::Image;
pub use core::Method;
pub use core::Object;
pub use core::Property;
pub use core::Type;
pub use core::ValueType;
pub use math::Color;
pub use math::Matrix2x2;
pub use math::Matrix3x3;
pub use math::Matrix4x4;
pub use math::Quaternion;
pub use math::Vector2;
pub use math::Vector3;
pub use math::Vector4;
pub use ptr::MutPtr;

Modules

collections
Collection types (List, Array, Dictionary, String) IL2CPP Collection types exports
components
Unity Component wrappers (GameObject, Transform, etc.) Unity Component system implementation
core
Core IL2CPP structures (Class, Method, Image, etc.) Core metadata and object wrappers.
math
Mathematical structures (Vector3, Quaternion, etc.) Math module exports
ptr
Pointer utilities Safe wrapper for valid mutable pointers