MethodSelector

Trait MethodSelector 

pub trait MethodSelector {
    // Required method
    fn matches(&self, method: &Method) -> bool;
}
Selector trait used by Class::method and crate::structs::Object::method.

Required Methods

fn matches(&self, method: &Method) -> bool

Returns true if the method matches the selector criteria

Implementations on Foreign Types

Source

impl MethodSelector for &str

Selects a method by name.

Source

fn matches(&self, method: &Method) -> bool

Source

impl MethodSelector for (&str, &[&str])

Selects a method by name and parameter type names.

Source

fn matches(&self, method: &Method) -> bool

Source

impl MethodSelector for (&str, usize)

Selects a method by name and parameter count.

Source

fn matches(&self, method: &Method) -> bool

Source

impl<const N: usize> MethodSelector for (&str, [&str; N])

Selects a method by name and parameter type names using a fixed-size array.

Source

fn matches(&self, method: &Method) -> bool

Implementors