pub trait MethodSelector {
// Required method
fn matches(&self, method: &Method) -> bool;
}Expand description
Selector trait used by Class::method and crate::structs::Object::method.
Required Methods
Implementations on Foreign Types
Sourceimpl MethodSelector for &str
Selects a method by name.
impl MethodSelector for &str
Selects a method by name.
Sourceimpl MethodSelector for (&str, &[&str])
Selects a method by name and parameter type names.
impl MethodSelector for (&str, &[&str])
Selects a method by name and parameter type names.
Sourceimpl MethodSelector for (&str, usize)
Selects a method by name and parameter count.
impl MethodSelector for (&str, usize)
Selects a method by name and parameter count.
Sourceimpl<const N: usize> MethodSelector for (&str, [&str; N])
Selects a method by name and parameter type names using a fixed-size array.
impl<const N: usize> MethodSelector for (&str, [&str; N])
Selects a method by name and parameter type names using a fixed-size array.